Environment Variables
Bossa does not currently read custom environment variables for configuration paths.
Use standard tool-specific environment variables (e.g., HOMEBREW_*) as needed.
Bossa does not currently read custom environment variables for configuration paths.
Use standard tool-specific environment variables (e.g., HOMEBREW_*) as needed.